@@ -21,7 +21,7 @@ import osso
 import pango
 #import threading
 #import re
-import os.path
+import os
 #import commands
 import cPickle
 from subprocess import *
@@ -132,7 +132,7 @@ class pygtkeditor_window(hildon.Window):
   ###############################################################################
   def load_last_opened_files(self):
     try:
-      fileHandle = open('/home/user/.pygtkeditor/history', 'rb')
+      fileHandle = open(os.path.expanduser("~")+'/.pygtkeditor/history', 'rb')
       try:
         self.last_opened_files = cPickle.load(fileHandle)
       finally:
@@ -145,7 +145,7 @@ class pygtkeditor_window(hildon.Window):
   ###############################################################################
   def save_last_opened_files(self):
     try:
-      fileHandle = open('/home/user/.pygtkeditor/history', 'wb')
+      fileHandle = open(os.path.expanduser("~")+'/.pygtkeditor/history', 'wb')
       try:
         cPickle.dump(self.last_opened_files,fileHandle,1)
       except StandardError,e:
@@ -154,10 +154,10 @@ class pygtkeditor_window(hildon.Window):
         fileHandle.close()
     except:
       try:
-        os.mkdir("/home/user/.pygtkeditor")
+        os.mkdir(os.path.expanduser("~")+"/.pygtkeditor")
       except StandardError,e:
         print e
-        f=file("/home/user/.pygtkeditor/history","w")
+        f=file(os.path.expanduser("~")+"/.pygtkeditor/history","w")
         f.close()
 
   ###############################################################################
@@ -970,7 +970,7 @@ class pygtkeditor_window(hildon.Window):
     dialog.set_logo_icon_name("pygtkeditor")
     dialog.set_authors(("Benoit HERVIER\n aka Khertan","","Thanks to :","Alterego for his help","Damien Moore for his patch"))
     dialog.set_comments('A source code editor for Maemo')
-    dialog.set_version("v2.4.0")
+    dialog.set_version("v2.4.1")
     dialog.set_license("This program is free software; you can redistribute it and/or\nmodify it under the terms of the GNU General Public License\nas published by the Free Software Foundation; either version 2\nof the License, or (at your option) any later version.")
     dialog.set_copyright("By Benoit HERVIER (aka Khertan)")
     dialog.set_website("http://khertan.net/")
@@ -1023,4 +1023,4 @@ class resultWindow:
   # @brief Close callback
   #############################################################################
   def on_close(self,widget):
-    win.hide()
\ No newline at end of file
+    win.hide()
